// @ts-ignore
const {$, $a} = window.fwdekker;


/**
 * Clears all validation messages from the given form.
 *
 * @param form the form to clear all validation messages in
 */
export function clearMessages(form: HTMLFormElement) {
    const formValidationInfo = $(".formValidationInfo", form);
    if (formValidationInfo !== null) clearMessage(formValidationInfo);

    $a("label", form).forEach(clearMessage);
}

/**
 * Clears the validation message from the given element.
 *
 * @param element the element to clear the validation message from
 */
export function clearMessage(element: HTMLElement) {
    element.classList.remove("success", "warning", "error");
    $(".validationInfo", element).innerText = "";
}

/**
 * Shows a success message at the given element.
 *
 * @param element the element to show the success message at
 * @param message the success message to display
 */
export function showSuccess(element: HTMLElement, message?: string) {
    element.classList.remove("warning", "error");
    element.classList.add("success");
    $(".validationInfo", element).innerText = message ?? "";
}

/**
 * Shows a warning message at the given element.
 *
 * @param element the element to show the warning message at
 * @param message the warning message to display
 */
export function showWarning(element: HTMLElement, message?: string) {
    element.classList.remove("success", "error");
    element.classList.add("warning");
    $(".validationInfo", element).innerText = message ?? "";
}

/**
 * Shows an error message at the given element.
 *
 * @param element the element to show the error message at
 * @param message the error message to display
 */
export function showError(element: HTMLElement, message?: string) {
    element.classList.remove("success", "warning");
    element.classList.add("error");
    $(".validationInfo", element).innerText = message ?? "";
}
